@@ -6,7 +6,6 @@ import importlib
 import numpy as np
 import pytest
 from emmet.core.tasks import TaskDoc
-from emmet.core.thermo import ThermoType
 from emmet.core.vasp.calc_types import CalcType
 from pymatgen.analysis.phase_diagram import PhaseDiagram
 from pymatgen.analysis.pourbaix_diagram import IonEntry, PourbaixDiagram, PourbaixEntry
@@ -27,12 +26,17 @@ from pymatgen.entries.mixing_scheme import MaterialsProjectDFTMixingScheme
 from pymatgen.entries.computed_entries import ComputedEntry, GibbsComputedStructureEntry
 from pymatgen.io.cif import CifParser
 from pymatgen.io.vasp import Chgcar
-from pymatgen.phonon.bandstructure import PhononBandStructureSymmLine
-from pymatgen.phonon.dos import PhononDos
+from emmet.core.phonon import PhononDOS, PhononBS
 
 from mp_api.client import MPRester
 from mp_api.client.core.client import MPRestError
 from mp_api.client.core.settings import MAPIClientSettings
+from mp_api.client.core.utils import _compare_emmet_ver
+
+if _compare_emmet_ver("0.85.0", ">="):
+    from emmet.core.types.enums import ThermoType
+else:
+    from emmet.core.thermo import ThermoType
 
 
 @pytest.fixture()
@@ -92,16 +96,14 @@ class TestMPRester:
         structs = mpr.get_structures("Mn-O", final=False)
         assert len(structs) > 0
 
-    @pytest.mark.skip(reason="Endpoint issues")
     def test_find_structure(self, mpr):
         path = os.path.join(MAPIClientSettings().TEST_FILES, "Si_mp_149.cif")
-        with open(path) as file:
-            data = mpr.find_structure(path)
-            assert len(data) > 0
+        data = mpr.find_structure(path)
+        assert isinstance(data, str) and data == "mp-149"
 
-            s = CifParser(file).get_structures()[0]
-            data = mpr.find_structure(s)
-            assert len(data) > 0
+        s = CifParser(path).get_structures()[0]
+        data = mpr.find_structure(s)
+        assert isinstance(data, str) and data == "mp-149"
 
     def test_get_bandstructure_by_material_id(self, mpr):
         bs = mpr.get_bandstructure_by_material_id("mp-149")
@@ -144,7 +146,13 @@ class TestMPRester:
             assert e.data.get("energy_above_hull", None) is not None
 
         # Conventional structure
-        entry = mpr.get_entry_by_material_id("mp-22526", conventional_unit_cell=True)[1]
+        entry = next(
+            e
+            for e in mpr.get_entry_by_material_id(
+                "mp-22526", conventional_unit_cell=True
+            )
+            if e.entry_id == "mp-22526-r2SCAN"
+        )
 
         s = entry.structure
         assert pytest.approx(s.lattice.a) == s.lattice.b
@@ -154,9 +162,14 @@ class TestMPRester:
         assert pytest.approx(s.lattice.gamma) == 120
 
         # Ensure energy per atom is same
-        prim = mpr.get_entry_by_material_id("mp-22526", conventional_unit_cell=False)[1]
-
-        s = prim.structure
+        entry = next(
+            e
+            for e in mpr.get_entry_by_material_id(
+                "mp-22526", conventional_unit_cell=False
+            )
+            if e.entry_id == "mp-22526-r2SCAN"
+        )
+        s = entry.structure
         assert pytest.approx(s.lattice.a) == s.lattice.b
         assert pytest.approx(s.lattice.a, abs=1e-3) == s.lattice.c
         assert pytest.approx(s.lattice.alpha, abs=1e-3) == s.lattice.beta
@@ -291,10 +304,10 @@ class TestMPRester:
 
     def test_get_phonon_data_by_material_id(self, mpr):
         bs = mpr.get_phonon_bandstructure_by_material_id("mp-2172")
-        assert isinstance(bs, PhononBandStructureSymmLine)
+        assert isinstance(bs, PhononBS)
 
         dos = mpr.get_phonon_dos_by_material_id("mp-2172")
-        assert isinstance(dos, PhononDos)
+        assert isinstance(dos, PhononDOS)
 
     def test_get_charge_density_from_material_id(self, mpr):
         chgcar = mpr.get_charge_density_from_material_id("mp-149")
@@ -304,7 +317,7 @@ class TestMPRester:
             "mp-149", inc_task_doc=True
         )
         assert isinstance(chgcar, Chgcar)
-        assert isinstance(task_doc, TaskDoc)
+        assert isinstance(TaskDoc.model_validate(task_doc.model_dump()), TaskDoc)
 
     def test_get_charge_density_from_task_id(self, mpr):
         chgcar = mpr.get_charge_density_from_task_id("mp-2246557")
@@ -314,7 +327,7 @@ class TestMPRester:
             "mp-2246557", inc_task_doc=True
         )
         assert isinstance(chgcar, Chgcar)
-        assert isinstance(task_doc, TaskDoc)
+        assert isinstance(TaskDoc.model_validate(task_doc.model_dump()), TaskDoc)
 
     def test_get_wulff_shape(self, mpr):
         ws = mpr.get_wulff_shape("mp-126")
